using System.Collections.Generic;

namespace Lextm.SharpSnmpLib.Mib
{
    internal sealed class NotificationType : IEntity
    {
        private readonly string _module;
        private string _parent;
        private readonly uint _value;
        private readonly string _name;
        private string _description;
        private string _type;

        public NotificationType(string module, IList<Symbol> header, Lexer lexer)
        {
            _module = module;
            _name = header[0].ToString();
            ParseDescription(header);
            ParseType(header);
            lexer.ParseOidValue(out _parent, out _value);
        }

        private void ParseType(IList<Symbol> header)
        {
            foreach (Symbol symbol in header)
            {
                if (symbol == Symbol.Syntax)
                {
                    Symbol temp = header[header.IndexOf(symbol) + 1];
                    while (temp == Symbol.EOL)
                        temp = header[header.IndexOf(temp) + 1];
                    _type = temp.ToString();
                    return;
                }
            }
        }

        private void ParseDescription(IList<Symbol> header)
        {
            foreach (Symbol symbol in header)
            {
                if (symbol == Symbol.Description)
                {
                    _description = header[(header.IndexOf(symbol) + 1)].ToString();
                    return;
                }
            }
            _description = "";
        }

        public string ModuleName
        {
            get { return _module; }
        }

        public string Parent
        {
            get { return _parent; }
            set { _parent = value; }
        }

        public uint Value
        {
            get { return _value; }
        }

        public string Name
        {
            get { return _name; }
        }
        
        public string Description
        {
            get { return _description; }
        }

        public string PropertyType
        {
            get { return _type; }
        }
    }
}