using System.Collections.Generic;

namespace Lextm.SharpSnmpLib.Mib
{
    /// <summary>
    /// Object identifier node.
    /// </summary>
    internal sealed class ObjectIdentity : IEntity
    {
        private readonly string _module;
        private readonly string _name;
        private string _parent;
        private readonly uint _value;
        private string _description;
        private string _type;
        
        /// <summary>
        /// Creates a <see cref="ObjectIdentity"/>.
        /// </summary>
        /// <param name="module">Module name</param>
        /// <param name="header">Header</param>
        /// <param name="lexer">Lexer</param>
        public ObjectIdentity(string module, IList<Symbol> header, Lexer lexer)
        {
            _module = module;
            _name = header[0].ToString();
            ParseDescription(header);
            ParseType(header);
            lexer.ParseOidValue(out _parent, out _value);
            if (_parent == "0")
            {
                _parent = "ccitt";
            }
        }

        private void ParseType(IList<Symbol> header)
        {
            foreach (Symbol symbol in header)
            {
                if (symbol == Symbol.Syntax)
                {
                    Symbol temp = header[header.IndexOf(symbol) + 1];
                    while (temp == Symbol.EOL)
                        temp = header[header.IndexOf(temp) + 1];
                    _type = temp.ToString();
                    return;
                }
            }
        }

        private void ParseDescription(IList<Symbol> header)
        {
            foreach (Symbol symbol in header)
            {
                if (symbol == Symbol.Description)
                {
                    _description = header[(header.IndexOf(symbol) + 1)].ToString();
                    return;
                }
            }
            _description = "";
        }

        /// <summary>
        /// Module name.
        /// </summary>
        public string ModuleName
        {
            get
            {
                return _module;
            }
        }
        
        /// <summary>
        /// Name.
        /// </summary>
        public string Name
        {
            get
            {
                return _name;
            }
        }
        
        /// <summary>
        /// Parent name.
        /// </summary>
        public string Parent
        {
            get { return _parent; }
            set { _parent = value; }
        }
        
        /// <summary>
        /// Value.
        /// </summary>
        public uint Value
        {
            get
            {
                return _value;
            }
        }
        
        public string Description
        {
            get { return _description; }
        }

        public string PropertyType
        {
            get { return _type; }
        }
    }
}